@@ -3,8 +3,6 @@ package Plagger::Plugin::Publish::Feed;
 use strict;
 use base qw( Plagger::Plugin );
 
-our $VERSION = 0.01;
-
 use XML::Feed;
 use XML::Feed::Entry;
 use XML::RSS::LibXML;
@@ -17,12 +15,12 @@ sub register {
     $context->register_hook(
         $self,
         'publish.feed' => \&publish_feed,
+        'plugin.init'  => \&plugin_init,
     );
-    $self->init_feed($context);
 }
 
-sub init_feed {
-    my($self, $context) = @_;
+sub plugin_init {
+    my($self, $context, $args) = @_;
 
     # check dir
     my $dir = $self->conf->{dir};
@@ -42,8 +40,6 @@ sub publish_feed {
     my $f = $args->{feed};
     my $feed_format = $conf->{format} || 'Atom';
 
-    local $XML::Atom::DefaultVersion = "1.0";
-
     # generate feed
     my $feed = XML::Feed->new($feed_format);
     $feed->title($f->title);
@@ -51,7 +47,8 @@ sub publish_feed {
     $feed->modified(Plagger::Date->now);
     $feed->generator("Plagger/$Plagger::VERSION");
     $feed->description($f->description || '');
-    $feed->author($f->author) if $f->primary_author;
+    $feed->author( $self->make_author($f->author, $feed_format) )
+        if $f->primary_author;
 
     if ($feed_format eq 'Atom') {
         $feed->{atom}->id("tag:plagger.org,2006:" . $f->id);
@@ -77,6 +74,7 @@ sub publish_feed {
         $entry->issued($e->date)   if $e->date;
         $entry->modified($e->date) if $e->date;
 
+        $entry->author( $self->make_author($e->author, $feed_format) );
         if ($feed_format eq 'RSS') {
             my $author = 'nobody@example.com';
             $author .= ' (' . $e->author . ')' if $e->author;
@@ -144,6 +142,18 @@ sub safe_filename {
     $path;
 }
 
+sub make_author {
+    my($self, $author, $feed_format) = @_;
+
+    if ($feed_format eq 'RSS') {
+        my $rfc822 = 'nobody@example.com';
+        $rfc822 .= ' (' . $author . ')' if $author;
+        return $rfc822;
+    } else {
+        return defined $author ? $author : 'nobody';
+    }
+}
+
 # XXX okay, this is a hack until XML::Feed is updated
 *XML::Feed::Entry::Atom::add_enclosure = sub {
     my($entry, $enclosure) = @_;
